package com.sun.org.apache.xml.internal.security.keys.content;

import com.sun.org.apache.xml.internal.security.utils.XMLUtils;
import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;
import com.sun.org.apache.xml.internal.security.keys.content.keyvalues.ECKeyValue;
import java.security.interfaces.ECPublicKey;
import java.security.interfaces.RSAPublicKey;
import java.security.interfaces.DSAPublicKey;
import java.security.PublicKey;
import org.w3c.dom.Element;
import com.sun.org.apache.xml.internal.security.keys.content.keyvalues.RSAKeyValue;
import com.sun.org.apache.xml.internal.security.keys.content.keyvalues.DSAKeyValue;
import org.w3c.dom.Document;
import com.sun.org.apache.xml.internal.security.utils.SignatureElementProxy;

public class KeyValue extends SignatureElementProxy implements KeyInfoContent
{
    public KeyValue(Document doc, DSAKeyValue toAppend) {
        super(doc);
        this.addReturnToSelf();
        this.appendSelf(toAppend);
        this.addReturnToSelf();
    }
    
    public KeyValue(Document doc, RSAKeyValue toAppend) {
        super(doc);
        this.addReturnToSelf();
        this.appendSelf(toAppend);
        this.addReturnToSelf();
    }
    
    public KeyValue(Document doc, Element toAppend) {
        super(doc);
        this.addReturnToSelf();
        this.appendSelf(toAppend);
        this.addReturnToSelf();
    }
    
    public KeyValue(Document doc, PublicKey publicKey) {
        super(doc);
        this.addReturnToSelf();
        if ((publicKey instanceof DSAPublicKey)) {
            this.appendSelf(new DSAKeyValue(this.getDocument(), publicKey));
            this.addReturnToSelf();
        }
        else if ((publicKey instanceof RSAPublicKey)) {
            this.appendSelf(new RSAKeyValue(this.getDocument(), publicKey));
            this.addReturnToSelf();
        }
        else if ((publicKey instanceof ECPublicKey)) {
            this.appendSelf(new ECKeyValue(this.getDocument(), publicKey));
            this.addReturnToSelf();
        }
        else {
            throw new IllegalArgumentException("The given PublicKey type " + publicKey + " is not supported. Only DSAPublicKey and RSAPublicKey and ECPublicKey types are currently supported");
        }
    }
    
    public KeyValue(Element element, String baseURI) throws XMLSecurityException {
        super(element, baseURI);
    }
    
    public PublicKey getPublicKey() throws XMLSecurityException {
        Element selectDsNode = XMLUtils.selectDsNode(this.getFirstChild(), "RSAKeyValue", 0);
        if (selectDsNode != null) {
            return new RSAKeyValue(selectDsNode, this.baseURI).getPublicKey();
        }
        Element selectDsNode2 = XMLUtils.selectDsNode(this.getFirstChild(), "DSAKeyValue", 0);
        if (selectDsNode2 != null) {
            return new DSAKeyValue(selectDsNode2, this.baseURI).getPublicKey();
        }
        return null;
    }
    
    @Override
    public String getBaseLocalName() {
        return "KeyValue";
    }
}
